==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/DeleteApnsSandboxChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteApnsSandboxChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest = {
    import DeleteApnsSandboxChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.wrap(buildAwsValue())
}
object DeleteApnsSandboxChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest =
      zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
  ) extends zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
  ): zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/DeleteApnsSandboxChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteApnsSandboxChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest = {
    import DeleteApnsSandboxChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.wrap(buildAwsValue())
}
object DeleteApnsSandboxChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest =
      zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
  ) extends zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteApnsSandboxChannelRequest
  ): zio.aws.pinpoint.model.DeleteApnsSandboxChannelRequest.ReadOnly =
    new Wrapper(impl)
}
